==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/it/settings.php <==
<?php

return [
    '1 month' => '1 mese',
    '1 week' => '1 settimana',
    '1 year' => '1 anno',
    '2 weeks' => '2 settimane',
    '3 months' => '3 mesi',
    '6 months' => '6 mesi',
    '<strong>Confirm</strong> icon deletion' => '<strong>Conferma</strong> l\'eliminazione dell\'icona',
    '<strong>Confirm</strong> image deletion' => '<strong>Conferma</strong> l\'eliminazione dell\'immagine',
    '<strong>Maintenance</strong> Mode' => 'Modalità <strong>Manutenzione</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Avviso:</strong> tutti gli utenti verranno disconnessi immediatamente, tranne gli amministratori.',
    'APC(u)' => 'APC(u)',
    'Activate' => 'Attiva',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Attivare la modalità di manutenzione e disabilitare l\'accesso alla piattaforma per gli utenti non amministratori?<br><br>',
    'Add OEmbed provider' => 'Aggiungi OEmbed provider',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Aggiungi testo informativo personalizzato per la modalità di manutenzione. Visualizzato nella pagina di accesso.',
    'Add new provider' => 'Aggiungi nuovo fornitore',
    'Advanced Settings' => 'Impostazioni avanzate',
    'Allow Self-Signed Certificates?' => 'Consenti certificati autocertificati?',
    'Allowed file extensions' => 'Estensioni file consentite',
    'Alphabetical' => 'Alfabetico',
    'Appearance Settings' => 'Impostazioni aspetto',
    'Auto format based on user language - Example: {example}' => 'Formatta in base alla lingua utente - Esempio: {example}',
    'Back to overview' => 'Indietro alla panoramica',
    'Base URL' => 'URL base',
    'Cache Backend' => 'Cache Backend',
    'Comma separated list. Leave empty to allow all.' => 'Elenco separato da virgola. Lasciare vuoto per consentire tutti.',
    'Could not send test email.' => 'Non è possibile mandare una email di prova.',
    'Currently no provider active!' => 'Al momento non ci sono fornitori attivi!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Al momento ci sono {count} elementi nel database a partire dal {dating}.',
    'Dashboard' => 'Bacheca',
    'Date input format' => 'Formato inserimento data',
    'Deactivate' => 'Disattiva',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Disattivare la modalità di manutenzione e consentire a tutti gli utenti di accedere nuovamente alla piattaforma?',
    'Default Expire Time (in seconds)' => 'Tempo di scadenza predefinito (in secondi)',
    'Default Timezone' => 'Fuso orario predefinito',
    'Default language' => 'Lingua predefinita',
    'Default pagination size (Entries per page)' => 'Misura predefinita dell\'impaginazione (Elementi per pagina)',
    'Default stream content order' => 'Ordine per il contenuto streaming predefinito',
    'Delete' => 'Cancella',
    'Display Name (Format)' => 'Mostra nome (Formato)',
    'Dropdown space order' => 'Ordine tendina Space',
    'E-Mail' => 'Email',
    'E-Mail reply-to' => 'E-mail per rispondi-a',
    'E-Mail sender address' => 'Indirizzo del mittente dell\'e-mail',
    'E-Mail sender name' => 'Nome del mittente dell\'e-mail',
    'E.g. http://example.com/humhub' => 'Esempio: http://example.com/humhub',
    'Edit OEmbed provider' => 'Modifica OEmbed provider',
    'Enable maintenance mode' => 'Abilita la modalità di manutenzione',
    'Enable user friendship system' => 'Abilita sistema di amicizia per gli utenti',
    'Enabled' => 'Abilitato',
    'Enabled OEmbed providers' => 'Fornitori OEmbed abilitati',
    'Encryption' => 'Crittografia',
    'Endpoint Url' => 'Endpoint Url',
    'Exclude media files from stream attachment list' => 'Escludi i file multimediali dall\'elenco degli allegati dello stream',
    'File' => 'File',
    'Firstname Lastname (e.g. John Doe)' => 'Nome Cognome (esempio: John Doe)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fisso (gg/mm/aaaa) - Esempio: {example}',
    'Friendship' => 'Amicizia',
    'General' => 'Generale',
    'General Settings' => 'Impostazioni generali',
    'HTML tracking code' => 'Codice HTML per il tracciamento',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Qui puoi configurare la registrazione e ulteriori impostazioni utenti del tuo social network.',
    'Here you can configure basic settings of your social network.' => 'Qui puoi configurare le impostazioni base del tuo social network.',
    'Horizontal scrolling images on a mobile device' => 'Scorrimento orizzontale delle immagini per dispositivi mobile',
    'Icon upload' => 'Carica icona',
    'Last visit' => 'Ultimo accesso',
    'Logo upload' => 'Carica Logo',
    'Mail Transport Type' => 'Tipo di Mail Transport',
    'Maintenance mode' => 'Modalità di manutenzione',
    'Maximum allowed age for logs.' => 'Tempo massimo consentito per i log.',
    'Maximum upload file size (in MB)' => 'Misura massima del file in upload (in MB)',
    'Mobile appearance' => 'Visualizzazione per dispositivi portatili',
    'Name of the application' => 'Nome dell\'applicazione',
    'No Proxy Hosts' => 'Nessun Host Proxy',
    'No caching' => 'Nessuna caching',
    'Notification Settings' => 'Impostazioni notifiche',
    'Old logs can significantly increase the size of your database while providing little information.' => 'I vecchi log aumentano significativamente la dimensione del database, ma forniscono poche informazioni utili.',
    'Optional. Default reply address for system emails like notifications.' => 'Opzionale. Indirizzo di risposta predefinito per le email di sistema come le notifiche',
    'PHP APC(u) Extension missing - Type not available!' => 'Estensione PHP APC(u) mancante - Tipo non trovabile!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP impostato ad un massimo di {maxUploadSize} MB',
    'Password' => 'Password',
    'Port' => 'Porta',
    'Port number' => 'Numero porta',
    'Prevent client caching of following scripts' => 'Blocca la cache del client per i seguenti script',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => 'Ora database segnalata: {dateTime}',
    'SMTP Options' => 'Opzioni SMTP',
    'Save' => 'Salva',
    'Save & Flush Caches' => 'Salva e svuota Cache',
    'Save & Test' => 'Salva e testa',
    'Saved' => 'Salvato',
    'Saved and flushed cache' => 'Cache salvata e attivata',
    'Saved and sent test email to: {address}' => 'Email di prova salvata e inviata a: {address}',
    'Server' => 'Server',
    'Server Timezone' => 'Fuso orario server',
    'Show introduction tour for new users' => 'Mostra il tour di introduzione ai nuovi utenti',
    'Show user profile post form on dashboard' => 'Mostra il form per i profili utente sulla bacheca',
    'Sort by creation date' => 'Ordina per data creazione',
    'Sort by update date' => 'Ordina per data aggiornamento',
    'Test message' => 'Messaggio di prova',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Queste impostazioni concernono argomenti avanzati del tuo social network.',
    'These settings refer to the appearance of your social network.' => 'Queste impostazioni concernono l\'aspetto del tuo social network.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Applica %url% come placeholder per gli URL. Il formato deve essere JSON. (es. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use X-Sendfile for File Downloads' => 'Usa X-Sendfile per scaricare i file',
    'Use the default swipe to show sidebar on a mobile device' => 'Utilizzare lo scorrimento predefinito per mostrare la barra laterale su un dispositivo mobile',
    'User' => 'Utente',
    'User Settings' => 'Impostazioni Utenti',
    'Username' => 'Username',
    'Username (e.g. john)' => 'Nome utente (esempio: john)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Puoi aggiungere del codice HTML snippet per le statistiche. Verrà aggiunto a tutte le pagine caricate.',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Non stai usando una icona al momento, carica il tuo logo ora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Non stai usando nessun logo al momento, carica il tuo logo ora.',
    'never' => 'mai',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/it/settings.php <==
<?php

return [
    '1 month' => '1 mese',
    '1 week' => '1 settimana',
    '1 year' => '1 anno',
    '2 weeks' => '2 settimane',
    '3 months' => '3 mesi',
    '6 months' => '6 mesi',
    '<strong>Confirm</strong> icon deletion' => '<strong>Conferma</strong> l\'eliminazione dell\'icona',
    '<strong>Confirm</strong> image deletion' => '<strong>Conferma</strong> l\'eliminazione dell\'immagine',
    '<strong>Maintenance</strong> Mode' => 'Modalità <strong>Manutenzione</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Avviso:</strong> tutti gli utenti verranno disconnessi immediatamente, tranne gli amministratori.',
    'Access Token' => 'Token di accesso',
    'Access token is not provided yet.' => 'Il token di accesso non è stato ancora fornito.',
    'Activate' => 'Attiva',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Attivare la modalità di manutenzione e disabilitare l\'accesso alla piattaforma per gli utenti non amministratori?<br><br>',
    'Add OEmbed provider' => 'Aggiungi OEmbed provider',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Aggiungi testo informativo personalizzato per la modalità di manutenzione. Visualizzato nella pagina di accesso.',
    'Add new provider' => 'Aggiungi nuovo fornitore',
    'Advanced Settings' => 'Impostazioni avanzate',
    'Allow Self-Signed Certificates?' => 'Consenti certificati autocertificati?',
    'Allowed file extensions' => 'Estensioni file consentite',
    'Alphabetical' => 'Alfabetico',
    'Appearance Settings' => 'Impostazioni aspetto',
    'Auto format based on user language - Example: {example}' => 'Formatta in base alla lingua utente - Esempio: {example}',
    'Back to overview' => 'Indietro alla panoramica',
    'Base URL' => 'URL base',
    'Comma separated list. Leave empty to allow all.' => 'Elenco separato da virgola. Lasciare vuoto per consentire tutti.',
    'Configuration (Use settings from configuration file)' => 'Configurazione (usa le impostazioni dal file di configurazione)',
    'Could not send test email.' => 'Non è possibile mandare una email di prova.',
    'Currently no provider active!' => 'Al momento non ci sono fornitori attivi!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Al momento ci sono {count} elementi nel database a partire dal {dating}.',
    'Custom DSN' => 'DSN personalizzato',
    'DSN' => 'DSN',
    'DSN Examples:' => 'Esempi DSN:',
    'Dashboard' => 'Bacheca',
    'Date input format' => 'Formato inserimento data',
    'Deactivate' => 'Disattiva',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Disattivare la modalità di manutenzione e consentire a tutti gli utenti di accedere nuovamente alla piattaforma?',
    'Default Timezone' => 'Fuso orario predefinito',
    'Default language' => 'Lingua predefinita',
    'Default pagination size (Entries per page)' => 'Misura predefinita dell\'impaginazione (Elementi per pagina)',
    'Default stream content order' => 'Ordine per il contenuto streaming predefinito',
    'Delete' => 'Cancella',
    'Dropdown space order' => 'Ordine tendina Space',
    'E-Mail' => 'Email',
    'E-Mail reply-to' => 'E-mail per rispondi-a',
    'E-Mail sender address' => 'Indirizzo del mittente dell\'e-mail',
    'E-Mail sender name' => 'Nome del mittente dell\'e-mail',
    'E.g. http://example.com/humhub' => 'Esempio: http://example.com/humhub',
    'Edit OEmbed provider' => 'Modifica OEmbed provider',
    'Embedded content requires the user\'s consent to be loaded' => 'Il contenuto incorporato richiede il consenso dell\'utente per essere caricato',
    'Enable maintenance mode' => 'Abilita la modalità di manutenzione',
    'Enable user friendship system' => 'Abilita sistema di amicizia per gli utenti',
    'Enabled' => 'Abilitato',
    'Enabled OEmbed providers' => 'Fornitori OEmbed abilitati',
    'Endpoint Url' => 'Endpoint Url',
    'Exclude media files from stream attachment list' => 'Escludi i file multimediali dall\'elenco degli allegati dello stream',
    'Firstname Lastname (e.g. John Doe)' => 'Nome Cognome (esempio: John Doe)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fisso (gg/mm/aaaa) - Esempio: {example}',
    'Friendship' => 'Amicizia',
    'General' => 'Generale',
    'General Settings' => 'Impostazioni generali',
    'HTML tracking code' => 'Codice HTML per il tracciamento',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Qui puoi configurare la registrazione e ulteriori impostazioni utenti del tuo social network.',
    'Here you can configure basic settings of your social network.' => 'Qui puoi configurare le impostazioni base del tuo social network.',
    'Horizontal scrolling images on a mobile device' => 'Scorrimento orizzontale delle immagini per dispositivi mobile',
    'Icon upload' => 'Carica icona',
    'Last visit' => 'Ultimo accesso',
    'Logo upload' => 'Carica Logo',
    'Mail Transport Type' => 'Tipo di Mail Transport',
    'Maintenance mode' => 'Modalità di manutenzione',
    'Maximum allowed age for logs.' => 'Tempo massimo consentito per i log.',
    'Maximum upload file size (in MB)' => 'Misura massima del file in upload (in MB)',
    'Mobile appearance' => 'Visualizzazione per dispositivi portatili',
    'Name of the application' => 'Nome dell\'applicazione',
    'No Delivery (Debug Mode, Save as file)' => 'Nessuna consegna (modalità debug, salvataggio come file)',
    'No Proxy Hosts' => 'Nessun Host Proxy',
    'Notification Settings' => 'Impostazioni notifiche',
    'Old logs can significantly increase the size of your database while providing little information.' => 'I vecchi log aumentano significativamente la dimensione del database, ma forniscono poche informazioni utili.',
    'Optional. Default reply address for system emails like notifications.' => 'Opzionale. Indirizzo di risposta predefinito per le email di sistema come le notifiche',
    'PHP (Use settings of php.ini file)' => 'PHP (usa le impostazioni del file php.ini)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP impostato ad un massimo di {maxUploadSize} MB',
    'Password' => 'Password',
    'Port' => 'Porta',
    'Port number' => 'Numero porta',
    'Provider Name' => 'Nome del provider',
    'Regular expression by which the link match will be checked.' => 'Espressione regolare con cui verrà verificata la corrispondenza del collegamento.',
    'Reported database time: {dateTime}' => 'Ora database segnalata: {dateTime}',
    'Save' => 'Salva',
    'Save & Flush Caches' => 'Salva e svuota Cache',
    'Save & Test' => 'Salva e testa',
    'Saved' => 'Salvato',
    'Saved and flushed cache' => 'Cache salvata e attivata',
    'Saved and sent test email to: {address}' => 'Email di prova salvata e inviata a: {address}',
    'Server' => 'Server',
    'Server Timezone' => 'Fuso orario server',
    'Show introduction tour for new users' => 'Mostra il tour di introduzione ai nuovi utenti',
    'Show user profile post form on dashboard' => 'Mostra il form per i profili utente sulla bacheca',
    'Sort by creation date' => 'Ordina per data creazione',
    'Sort by update date' => 'Ordina per data aggiornamento',
    'Test message' => 'Messaggio di prova',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Queste impostazioni concernono argomenti avanzati del tuo social network.',
    'These settings refer to the appearance of your social network.' => 'Queste impostazioni concernono l\'aspetto del tuo social network.',
    'Url Pattern' => 'Modello dell\'URL',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Applica %url% come placeholder per gli URL. Il formato deve essere JSON. (es. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use SMTPS' => 'Usa SMTP',
    'Use X-Sendfile for File Downloads' => 'Usa X-Sendfile per scaricare i file',
    'User' => 'Utente',
    'User Display Name' => 'Nome visualizzato utente',
    'User Display Name Subtitle' => 'Nome visualizzato utente Sottotitolo',
    'User Settings' => 'Impostazioni Utenti',
    'Username' => 'Nome utente',
    'Username (e.g. john)' => 'Nome utente (esempio: john)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Puoi aggiungere del codice HTML snippet per le statistiche. Verrà aggiunto a tutte le pagine caricate.',
    'You can find more configuration options here:' => 'Puoi trovare altre opzioni di configurazione qui:',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Non stai usando una icona al momento, carica il tuo logo ora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Non stai usando nessun logo al momento, carica il tuo logo ora.',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => 'per esempio. 25 (per SMTP) o 465 (per SMTPS)',
    'e.g. localhost' => 'per esempio. localhost',
    'e.g. smtps://user:pass@smtp.example.com:port' => 'per esempio. smtps://user:pass@smtp.example.com:port',
    'never' => 'mai',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
